@@ -1,4 +1,5 @@
 <?php
+
 // Icinga Web 2 X.509 Module | (c) 2018 Icinga GmbH | GPLv2
 
 namespace Icinga\Module\X509;
@@ -10,7 +11,7 @@ use Icinga\Repository\IniRepository;
  */
 class JobsIniRepository extends IniRepository
 {
-    protected $queryColumns = array('jobs' => array('name', 'cidrs', 'ports', 'schedule'));
+    protected $queryColumns = ['jobs' => ['name', 'cidrs', 'ports', 'exclude_targets', 'schedule', 'frequencyType']];
 
     protected $configs = array('jobs' => array(
         'module'    => 'x509',
